PqCallbackKeyCustodyStore class

Implemented types

Constructors

PqCallbackKeyCustodyStore({required PqKeyCustodyPut putDocument, required PqKeyCustodyGet getDocument, required PqKeyCustodyDelete deleteDocument})
const

Properties

deleteDocument PqKeyCustodyDelete
final
getDocument PqKeyCustodyGet
final
hashCode int
The hash code for this object.
no setterinherited
putDocument PqKeyCustodyPut
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete(String storageId) Future<void>
override
get(String storageId) Future<Map<String, Object?>?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
put(String storageId, Map<String, Object?> document) Future<void>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited