PqClassicalSignatureAlgorithm enum

Inheritance
Available extensions

Values

ed25519 → const PqClassicalSignatureAlgorithm
const PqClassicalSignatureAlgorithm(id: 'ed25519', publicKeyBytes: 32, secretKeyBytes: 32, signatureBytes: 64)
ecdsaP256 → const PqClassicalSignatureAlgorithm
const PqClassicalSignatureAlgorithm(id: 'ecdsa-p256', publicKeyBytes: 65, secretKeyBytes: 32, signatureBytes: 64)

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
final
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
publicKeyBytes int
Public-key length in bytes (Ed25519: 32; ECDSA-P256 uncompressed: 65).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secretKeyBytes int
Secret-key length in bytes (the 32-byte Ed25519 seed / EC scalar).
final
signatureBytes int
Signature length in bytes (Ed25519: 64; ECDSA-P256 raw r||s: 64).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

byId(String id) PqClassicalSignatureAlgorithm

Constants

values → const List<PqClassicalSignatureAlgorithm>
A constant List of the values in this enum, in order of their declaration.