PqForgeBytes class

Backward-compatible byte utility name from the V0.1 facade.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

concat(Iterable<Uint8List> chunks) Uint8List
constantTimeEquals(Uint8List expected, Uint8List supplied) bool
copy(Uint8List value) Uint8List
hmacSha256({required Uint8List key, required Uint8List data}) Uint8List
lengthPrefixed(Iterable<Uint8List> fields) Uint8List
randomBytes(int length) Uint8List
sha256(Uint8List data) Uint8List
uint32(int value) Uint8List
uint64(int value) Uint8List
utf8Bytes(String value) Uint8List