PqHybridKeyAgreementResult class
Constructors
- PqHybridKeyAgreementResult({required PqHybridKeyAgreementRequest request, required Uint8List sessionKey})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- request → PqHybridKeyAgreementRequest
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionKey → Uint8List
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited