PqHybridSignature class
Constructors
- PqHybridSignature({required Uint8List pqcSignature, required Uint8List classicalSignature, required PqSignatureAlgorithm pqcAlgorithm, required PqClassicalSignatureAlgorithm classicalAlgorithm, PqDualSignaturePolicy policy = PqDualSignaturePolicy.requireBoth})
Properties
- classicalAlgorithm → PqClassicalSignatureAlgorithm
-
final
- classicalSignature → Uint8List
-
final
- dualSignature → PqDualSignature
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- policy → PqDualSignaturePolicy
-
final
- pqcAlgorithm → PqSignatureAlgorithm
-
final
- pqcSignature → Uint8List
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
Map< String, Object?> json) → PqHybridSignature