PqMemoryKeyCustodyStore class

Implemented types

Constructors

PqMemoryKeyCustodyStore()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
snapshot Map<String, Map<String, Object?>>
no setter

Methods

delete(String storageId) Future<void>
override
get(String storageId) Future<Map<String, Object?>?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
put(String storageId, Map<String, Object?> document) Future<void>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited