PqPackEntry class
One file to pack: its archive-relative path and its on-disk source path.
Constructors
- PqPackEntry({required String relativePath, required String sourcePath})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- relativePath → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourcePath → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited