PqStreamingStats class

Outcome of a streaming encrypt/decrypt: byte and frame counts for logging.

Constructors

PqStreamingStats({required int plaintextBytes, required int containerBytes, required int frameCount, required bool signed})
const

Properties

containerBytes int
final
frameCount int
final
hashCode int
The hash code for this object.
no setterinherited
plaintextBytes int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signed bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited