PqClassicalSignatureKeyPair class
A classical signature key pair as raw bytes, so both backends — Ed25519 via
package:cryptography and ECDSA-P256 via PqEcdsaP256 — share one type.
Constructors
- PqClassicalSignatureKeyPair({required PqClassicalSignatureAlgorithm algorithm, required Uint8List publicKey, required Uint8List secretKey})
Properties
- algorithm → PqClassicalSignatureAlgorithm
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- publicKey → Uint8List
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secretKey → Uint8List
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited