PqForgeCryptographyAeadEngine class final
PqForgeAeadEngine implemented with package:cryptography.
On platforms with hardware-accelerated OS bindings (and on the web via
package:cryptography's browser implementations) this can be substantially
faster than the pure-Dart engine. The cryptography package returns the MAC
separately in a crypto.SecretBox; this engine appends it to the ciphertext
to produce the same ciphertext || tag body the PointyCastle engine emits.
- Implemented types
Constructors
- PqForgeCryptographyAeadEngine(PqForgeCipherSuite cipherSuite)
Properties
- cipherSuite → PqForgeCipherSuite
-
The cipher suite this engine implements.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- provider → PqForgeEngineProvider
-
The backend that powers this engine.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
open(
{required Uint8List key, required Uint8List nonce, required Uint8List cipherTextWithTag, required Uint8List aad}) → Future< Uint8List> -
Decrypts a
ciphertext || tagcipherTextWithTagbody.override -
seal(
{required Uint8List key, required Uint8List nonce, required Uint8List plaintext, required Uint8List aad}) → Future< Uint8List> -
Encrypts
plaintext, returningciphertext || tag(tag appended).override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited