PqRecipientSpec class
One additional recipient of a multi-recipient encryption: their ML-KEM public key, an optional X25519 public key (making their key wrap hybrid), and an optional key id recorded in the entry for fast unwrap routing.
Constructors
- PqRecipientSpec({required Uint8List kemPublicKey, Uint8List? kexPublicKey, String? keyId})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- kemPublicKey → Uint8List
-
final
- kexPublicKey → Uint8List?
-
final
- keyId → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited